<?php
namespace Teknisa\PLA\Modules\Prato\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DataSource\DataSet as DataSet_Source;

class ConsultaNutrientes extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "consulta_nutrientes";
    protected $parameterBagColumns = array("CDFILAUXPRAT", "CDPRATO", "CDFILIAL", "CDSERVFILI", "CDFILCENTPME", "CDTIPOCARD", "FILIPROC");

    protected $pratoService;

    public function __construct(
        $crudService, $parameterBag,
        \Teknisa\PLA\Modules\Prato\Services\PratoService $pratoService
    ) {
        parent::__construct($crudService, $parameterBag);
        $this->pratoService = $pratoService;
    }

    public function calculaNDPCal(
        \Zeedhi\Framework\DTO\Request\Row $request,
        \Zeedhi\Framework\DTO\Response $response
    ){
        try {
            $row = $request->getRow();

            $filial = $row['CDFILIAL'];
            $filProc = $row['CDFILIPROC'];
            $servico = $row['CDSERVFILI'];
            $filAux = $row['CDFILAUXPRAT'];
            $cdprato = $row['CDPRATO'];
            $filMer = $row['CDFILCENTPME'];
            $tipoCard = $row['CDTIPOCARD'];
            $merenda = $row['MERENDA'];
            $resultado = '';

            $conn = $this->pratoService->getConnection();
            $ndpcal = new StoredProcedure($conn, 'NDPCAL_DO_PRATO_PLA');

            $ndpcal->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $filial, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_CDFILIPROC', Param::PARAM_INPUT, $filProc, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_CDSERVFILI', Param::PARAM_INPUT, $servico, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_CDFILAUXPRAT', Param::PARAM_INPUT, $filAux, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_CDPRATO', Param::PARAM_INPUT, $cdprato, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_CDFILCENTPME', Param::PARAM_INPUT, $filMer, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_CDTIPOCARD', Param::PARAM_INPUT, $tipoCard, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_MERENDA', Param::PARAM_INPUT, $merenda, Param::PARAM_TYPE_STR));
            $ndpcal->addParam(new Param('P_NDPCAL_DO_PRATO', Param::PARAM_OUTPUT, $resultado, Param::PARAM_TYPE_STR));

            $ndpcal->execute();
            $response->addDataset(new DataSet_Source('VALOR', array($resultado)));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function retornaCorSinasafra(
        \Zeedhi\Framework\DTO\Request\Row $request,
        \Zeedhi\Framework\DTO\Response $response
    ){
        try {
            $row = $request->getRow();
            $valor = $row['VALOR'];
            $cor = $this->pratoService->retornaCorSinaSafra($valor);

            $response->addDataset(new DataSet_Source('VALOR', array($cor)));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }


}